﻿using System;
using System.Configuration;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;

using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace CSSamples.Samples.Layers
{
    public partial class UseGoogleMap : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapUnit = GeographyUnit.Meter;

                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.MouseCoordinate.Enabled = true;

                //
                //Setting base overlay
                // 

                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
                google.GoogleMapType = GoogleMapType.Normal;

                Map1.CustomOverlays.Add(google);



                Proj4Projection proj4 = new Proj4Projection();
                proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

                //
                // Get feature list
                //

                List<String> colNames = new List<String>();
                colNames.Add("Name");
                /// and so on....12 columns

                Collection<Feature> tempFeatures = new Collection<Feature>();

                Dictionary<string, string> columnValsLA = new Dictionary<string, string>();                
                columnValsLA.Add(colNames[0], "LA");

                PointShape ptLA = new PointShape(-118.28109, 34.505363);
                ptLA.Id = "LA";
                Feature feature1 = new Feature(ptLA, columnValsLA);

                tempFeatures.Add(feature1);

                Dictionary<string, string> columnValsSanDiego = new Dictionary<string, string>();
                columnValsSanDiego.Add(colNames[0], "San Diego");
                PointShape ptSanDiego = new PointShape(-117.28109, 33.505363);      
                ptSanDiego.Id = "San Diego";
                Feature feature2 = new Feature( ptSanDiego, columnValsSanDiego);

                tempFeatures.Add(feature2);

                //
                // Add features on Marker (overlay) and Label layer
                //

                InMemoryMarkerOverlay markerOverlay = new InMemoryMarkerOverlay("MarkerOverlay");               

                foreach (Feature feat in tempFeatures)
                {
                  markerOverlay.Features.Add(feat.Id, feat);
                }

                InMemoryFeatureLayer layerLabelMarkers = new InMemoryFeatureLayer();
               //  layerLabelMarkers.DrawingMarginPercentage = dDrawingMargin;
                layerLabelMarkers.Open();
                foreach (String colName in colNames)
                {
                  layerLabelMarkers.Columns.Add(new FeatureSourceColumn(colName));
                }
                layerLabelMarkers.Close();

                foreach (Feature feat in tempFeatures)
                {
                  layerLabelMarkers.InternalFeatures.Add(feat.Id, feat);
                }

                //layerLabelMarkers.InternalFeatures.Add("LA", feature1);
                //layerLabelMarkers.InternalFeatures.Add("SanDiego", feature2);

                //
                // Setting label style
                //

                layerLabelMarkers.FeatureSource.Projection = proj4;

                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.RequiredColumnNames.Add(colNames[0]);

                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle =
                    TextStyles.CreateSimpleTextStyle(colNames[0], "Verdana",
                    10, DrawingFontStyles.Bold,
                            //GeoColor.StandardColors.White, -22, 15);
                    GeoColor.StandardColors.Red, -10, -25);

                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.GridSize = 30;
                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.BestPlacement = true;

                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.SplineType = SplineType.ForceSplining;
                
                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.SuppressPartialLabels = false;
                layerLabelMarkers.ZoomLevelSet.ZoomLevel07.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


                layerLabelMarkers.ZoomLevelSet.ZoomLevel19.Scale = 0;
                layerLabelMarkers.ZoomLevelSet.ZoomLevel19.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                //
                // Setting marker style
                // 
                markerOverlay.FeatureSource.Projection = proj4;

                markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.WebImage = new WebImage("../../theme/default/img/marker_green.gif", 21, 25);
                //markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.ContentHtml = contentHtml.ToString();
                markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.Width = 450;
                markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.Height = 290;
                markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.IsVisible = false;
                markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultMarkerStyle.Popup.AutoPan = true;
                markerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                // 
                //
                //
                LayerOverlay overlayLabels = new LayerOverlay("LabelOverlay");
                overlayLabels.IsBaseOverlay = false;
                overlayLabels.Layers.Add("LabelLayer", layerLabelMarkers);
                overlayLabels.IsVisible = true;

                Map1.CustomOverlays.Add(overlayLabels);
                Map1.CustomOverlays.Add(markerOverlay);

                Map1.SyncClientZoomLevels(layerLabelMarkers.ZoomLevelSet);
                
            }
        }
    }
}
